'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

/**
 * Combine the given strings and token names to give a msgid string.
 *
 * @param {Array.<string>} strings Template strings as given to the tagged template literal
 * @param {Array.<{name}>} tokens Tokens that contain a `name` field
 * @return {string} A msgid that contains `name` placeholders for substitutions
 */
var getTemplate = exports.getTemplate = function getTemplate(strings, tokens) {
  var names = tokens.reduce(function (reduced, _ref) {
    var name = _ref.name;
    return [].concat(_toConsumableArray(reduced), [name]);
  }, []);

  return strings.map(function (v, i) {
    return i in names ? '' + v + names[i] : v;
  }).join('');
};

/**
 * Make substitutions back into the translated string.
 *
 * @param {string} msgstr A translated string that contains token names
 * @param {Array.<{name, key, value}>} tokens Substitution tokens
 * @param {function} finaliseToken Transform of token to final value
 * @return {string|Array} A simple string or an Array of string and complex types
 */
var makeSubstitutions = exports.makeSubstitutions = function makeSubstitutions(_ref2) {
  var msgstr = _ref2.msgstr,
      tokens = _ref2.tokens,
      finaliseToken = _ref2.finaliseToken;

  var primitiveToString = function primitiveToString(value) {
    return value === null || ['undefined', 'boolean', 'number'].includes(typeof value === 'undefined' ? 'undefined' : _typeof(value)) ? String(value) : value;
  };

  var elements = tokens.reduce(function (reduced, _ref3, i) {
    var name = _ref3.name;

    if (name.length) {
      var completed = reduced.slice(0, -1);
      var remaining = reduced[reduced.length - 1] || '';
      var split = remaining.split(name);
      if (split.length > 1) {
        var unsplit = split.slice(1).join(name);
        return [].concat(_toConsumableArray(completed), [split[0], i, unsplit]);
      }
    }
    return reduced;
  }, [msgstr]).filter(function (v) {
    return typeof v !== 'string' || v.length;
  });

  var substituted = elements.reduce(function (reduced, v) {
    // cast primitives to string
    var pending = typeof v === 'number' ? primitiveToString(finaliseToken(tokens[v], reduced.length)) : v;

    if (reduced.length === 0) {
      return [pending];
    } else {
      // collapse adjoining strings
      var rest = reduced.slice(0, -1);
      var last = reduced[reduced.length - 1];
      return typeof pending === 'string' && typeof last === 'string' ? [].concat(_toConsumableArray(rest), ['' + last + pending]) : [].concat(_toConsumableArray(rest), [last, pending]);
    }
  }, []);

  return substituted.every(function (v) {
    return typeof v === 'string';
  }) ? substituted.join('') : substituted;
};